@@ -196,9 +196,8 @@ class dyagram:
                 try:
                     diffs = self.get_state_diff(state, self.topology) # state is the state file on record and topology is current state
                 except Exception as e:
-                    print("EXCEPTION")
                     tb = self.get_traceback()
-                    print(tb)
+                    print(f"DIFF TB: {tb}")
                 # print to screen the diffs
                 print("DIFFS\n")
                 for ip in diffs:
@@ -392,6 +391,7 @@ class dyagram:
                     device_diffs[s['devices'][device_elem]['inventory_ip']] = {"added": [], "removed": [],
                                                                                "changed": []}
 
+
                 if category == "dynamic_routing_neighbors":
                     if 'eigrp' in diff:
                         routing_protocol = "EIGRP"
@@ -411,7 +411,6 @@ class dyagram:
 
                 elif category == "layer2":
                     if diff_type != "changed":
-                        print(diff_resp[k][diff])
                         device_diffs[s['devices'][device_elem]['inventory_ip']][diff_type].append(
                             f"LLDP Neighbor {diff_resp[k][diff]['hostname']} (Chassis ID: {diff_resp[k][diff]['chassis_id']})")
 
@@ -728,7 +727,6 @@ class dyagram:
             for i in self.topology["devices"]:
                 if i['inventory_ip'] == device:
                     i['hostname'] = lldp_nei_json['hostname']
-                    print(lldp_nei_json['hostname'])
                     lldp_nei_json.pop("hostname")
                     i['layer2'] = lldp_nei_json
                     break
@@ -737,7 +735,6 @@ class dyagram:
             self._devices_queried.append(device)
         except:
             tb = self.get_traceback()
-            print("EXCEPTION THROWN WHEN TRYING TO GET HOSTNAME")
             self.log.info(f"EXCEPTION01 THROWN IN _discover_lldp_neighbors_by_ssh : {tb}")
 
 
@@ -767,7 +764,7 @@ class dyagram:
             return None
 
 
-        elif os in ["nx_os", "ios_xe"]:
+        elif netmiko_session.device_type in ["cisco_nxos", "cisco_xe", "cisco_ios"]:
             output = netmiko_session.send_command("sh interface | inc bia ")
             re_resp = re.findall(
                 '(?<=bia\s)[a-f\d][a-f\d][a-f\d][a-f\d]\.[a-f\d][a-f\d][a-f\d][a-f\d]\.[a-f\d][a-f\d][a-f\d][a-f\d]',
@@ -780,8 +777,9 @@ class dyagram:
             [chassis_ids.append(i) for i in re_resp if i not in chassis_ids]
             return chassis_ids
 
-        elif os == "ios_xr":
+        elif netmiko_session.device_type == "cisco_xr":
             output = netmiko_session.send_command("show lldp")
+            print(f"OUTPUT OF SH LLDP TO GET CHASSIS ID {output}")
             return [re.search("(?<=Chassis ID:\s).*", output).group(0)]
 
 
@@ -847,7 +845,9 @@ class dyagram:
 
 
     def _get_lldp_neighbors_ssh_textfsm(self, netmiko_session):
-        os = self._get_os_version(netmiko_session)
+        #os = self._get_os_version(netmiko_session)
+        os = self.get_device_type(netmiko_session.host)
+
         lldp_neighbors_output = netmiko_session.send_command("show lldp neighbors det", use_textfsm=True)
         if type(lldp_neighbors_output) == str:
             return lldp_neighbors_output
@@ -870,12 +870,12 @@ class dyagram:
 
     def _get_lldp_neighbors_ssh_regex(self, netmiko_session):
 
-        os = self._get_os_version(netmiko_session)
+        # os = self._get_os_version(netmiko_session)
         netmiko_session.host = os
 
         lldp_neighbors_output = netmiko_session.send_command("show lldp neighbors det")
         cdp_info_json = {"hostname": self._get_hostname(netmiko_session),
-                         "chassis_ids": self._get_chassis_ids(netmiko_session, os),
+                         "chassis_ids": self._get_chassis_ids(netmiko_session),
                          "neighbors": []}
 
         regex_strs = self._get_lldp_neighbor_regex_strings(os)
@@ -979,9 +979,7 @@ class dyagram:
             else:
                 self.log.info(f"DEVICE: {netmiko_session.host} - SSH : Querying for hostname - START")
                 sh_run_output = netmiko_session.send_command("sh run | inc hostname")
-                print("BEFORE HOSTNAME")
                 hostname = re.search("hostname\s+(.*)", sh_run_output).group(1)
-                print(f"HOSTNAME {hostname}")
                 self.log.info(f"DEVICE: {netmiko_session.host} - SSH : Querying for hostname - SUCCESSFUL")
 
                 return hostname
